"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const harmony_1 = require("@teambit/harmony");
const ui_1 = require("@teambit/ui");
const react_router_aspect_1 = require("./react-router.aspect");
const route_context_1 = require("./route-context");
class ReactRouterUI {
    constructor(
    /**
     * route slot.
     */
    routeSlot, 
    /**
     *
     */
    routeChangeListener) {
        this.routeSlot = routeSlot;
        this.routeChangeListener = routeChangeListener;
        this.routingMode = route_context_1.Routing.url;
        this.unregisterListener = undefined;
        /** (internal method) sets the routing engine for navigation methods */
        this.setRouter = (routerHistory) => {
            var _a;
            this.routerHistory = routerHistory;
            (_a = this.unregisterListener) === null || _a === void 0 ? void 0 : _a.call(this);
            this.unregisterListener = routerHistory.listen((...args) => {
                this.routeChangeListener.values().forEach((listener) => listener(...args));
            });
        };
        /**
         * change browser location
         */
        this.navigateTo = (
        /** destination */
        path, state) => {
            var _a;
            (_a = this.routerHistory) === null || _a === void 0 ? void 0 : _a.push(path, state);
        };
    }
    /**
     * render all slot routes.
     */
    renderRoutes(routes) {
        return (react_1.default.createElement(route_context_1.RouteContext, { routeSlot: this.routeSlot, rootRoutes: routes, reactRouterUi: this, routing: this.routingMode }));
    }
    /** decides how navigation is stored and applied.
     * Url - updates the `window.location.pathname`.
     * Hash - updates `window.location.hash`.
     * InMemory - store state internally and don't update the browser.
     */
    setRoutingMode(routing) {
        this.routingMode = routing;
    }
    /**
     * register a new route.
     */
    register(route) {
        this.routeSlot.register(route);
        return this;
    }
    registerListener(listener) {
        this.routeChangeListener.register(listener);
    }
    static provider(deps, config, [routeSlot, routeChangeSlot]) {
        return __awaiter(this, void 0, void 0, function* () {
            return new ReactRouterUI(routeSlot, routeChangeSlot);
        });
    }
}
exports.ReactRouterUI = ReactRouterUI;
ReactRouterUI.slots = [harmony_1.Slot.withType(), harmony_1.Slot.withType()];
ReactRouterUI.runtime = ui_1.UIRuntime;
react_router_aspect_1.ReactRouterAspect.addRuntime(ReactRouterUI);
//# sourceMappingURL=react-router.ui.runtime.js.map